region_mappings = {
    # Asia Pacific
    "CN": "cn-hongkong",  # China -> Hong Kong
    "HK": "cn-hongkong",  # Hong Kong
    "TW": "cn-hongkong",  # Taiwan -> Hong Kong
    "MO": "cn-hongkong",  # Macau -> Hong Kong
    # Southeast Asia
    "SG": "ap-southeast-1",  # Singapore
    "MY": "ap-southeast-3",  # Malaysia
    "ID": "ap-southeast-5",  # Indonesia
    "TH": "ap-southeast-1",  # Thailand -> Singapore
    "VN": "ap-southeast-1",  # Vietnam -> Singapore
    "PH": "ap-southeast-1",  # Philippines -> Singapore
    "BN": "ap-southeast-1",  # Brunei -> Singapore
    "KH": "ap-southeast-1",  # Cambodia -> Singapore
    "LA": "ap-southeast-1",  # Laos -> Singapore
    "MM": "ap-southeast-1",  # Myanmar -> Singapore
    # Australia/Oceania
    "AU": "ap-southeast-2",  # Australia
    "NZ": "ap-southeast-2",  # New Zealand -> Australia
    "FJ": "ap-southeast-2",  # Fiji -> Australia
    "PG": "ap-southeast-2",  # Papua New Guinea -> Australia
    # South Asia
    "IN": "ap-south-1",  # India
    "LK": "ap-south-1",  # Sri Lanka -> India
    "PK": "ap-south-1",  # Pakistan -> India
    "BD": "ap-south-1",  # Bangladesh -> India
    "NP": "ap-south-1",  # Nepal -> India
    "BT": "ap-south-1",  # Bhutan -> India
    "MV": "ap-south-1",  # Maldives -> India
    # Middle East
    "AE": "me-east-1",  # UAE
    "SA": "me-east-1",  # Saudi Arabia -> UAE
    "QA": "me-east-1",  # Qatar -> UAE
    "KW": "me-east-1",  # Kuwait -> UAE
    "BH": "me-east-1",  # Bahrain -> UAE
    "OM": "me-east-1",  # Oman -> UAE
    "IL": "me-east-1",  # Israel -> UAE
    "TR": "me-east-1",  # Turkey -> UAE
    # Europe
    "DE": "eu-central-1",  # Germany
    "FR": "eu-central-1",  # France -> Germany
    "IT": "eu-central-1",  # Italy -> Germany
    "ES": "eu-central-1",  # Spain -> Germany
    "GB": "eu-central-1",  # UK -> Germany
    "IE": "eu-central-1",  # Ireland -> Germany
    "NL": "eu-central-1",  # Netherlands -> Germany
    "BE": "eu-central-1",  # Belgium -> Germany
    "CH": "eu-central-1",  # Switzerland -> Germany
    "AT": "eu-central-1",  # Austria -> Germany
    "PL": "eu-central-1",  # poland -> Germany
    # North America
    "US": "us-east-1",  # USA
    "CA": "us-east-1",  # Canada -> US East
    "MX": "us-west-1",  # Mexico -> US West
    # South America
    "BR": "us-east-1",  # Brazil -> US East
    "AR": "us-east-1",  # Argentina -> US East
    "CL": "us-east-1",  # Chile -> US East
    "CO": "us-east-1",  # Colombia -> US East
    "PE": "us-east-1",  # Peru -> US East
}
