class tmp_constant:
    ALGECC = "ecc"
    ALGHMACMD5 = "hmacmd5"
    ALGNONE = "none"
    ALINK_SECURE_URI_SCHEME = "coaps"
    ALINK_URI_SCHEME = "coap"
    AUTH_VER = "1.0"
    CONFIG_TYPE_CLIENT = "ClientAuthInfo"
    CONFIG_TYPE_PROVISION_RECEIVER = "SetupData"
    CONFIG_TYPE_SERVER = "ServerAuthInfo"
    DATA_KEY_DEVICENAME = "MAC"
    DATA_KEY_DEVICE_WIFI_STATUS = "wifiEnabled"
    DEFAULT_COAP_SECURE_PORT = 5684
    DEFAULT_COAP_UDP_PORT = 5683
    DEFAULT_MULTI_CAST_ADDRESS = "224.0.1.187"
    DEVICES = "devices"
    DEVICE_DATA_FORMAT_ALINK = "ALINK_FORMAT"
    DEVICE_IOTID = "iotId"
    DEVICE_MODEL = "deviceModel"
    DEVICE_MODEL_EVENTS = "events"
    DEVICE_MODEL_PROPERTIES = "properties"
    DEVICE_MODEL_SERVICES = "services"
    DEVICE_MODEL_TYPE = "model"
    DEVICE_NAME = "deviceName"
    DEVICE_NAME_POSITION = 2
    DEVICE_PRODUCT_KEY = "productKey"
    DEVICE_PROFILE = "profile"
    EVENT_PROPERTY_URI_POST = "post"
    EVENT_PROPERTY_URI_POST_REPLY = "post_reply"
    EVENT_PROPERTY_URI_PRE = "thing/event/property"
    EVENT_URI_POST = "post"
    EVENT_URI_PRE = "thing/event"
    EXPAND_SPLITE = "."
    GROUP_CLOUD_ROLE_COTROLLER = "COTROLLER"
    GROUP_CLOUD_ROLE_DEVICE = "DEVICE"
    GROUP_DEVICE_LOCAL_STATUS_OFFLINE = 3
    GROUP_DEVICE_LOCAL_STATUS_ONLINE = 1
    GROUP_LOCAL_SATUS_ALLOFFLINE = 2
    GROUP_LOCAL_SATUS_ALLONLINE = 0
    GROUP_LOCAL_SATUS_PARTONLINE = 1
    GROUP_OP_ADD = "add"
    GROUP_OP_DEL = "del"
    GROUP_ROLE_CONTROLLER = "cloud_ctl"
    GROUP_ROLE_DEVICE = "cloud_dev"
    GROUP_ROLE_UNKNOWN = "null"
    HEARTBEAT_DEFAULT_TIME = 600000
    HEARTBEAT_MAX_RETRY_TIME = 3
    IDENTIFIER_DEVICENOTIFY = "devnotify"
    IDENTIFIER_RAW_DATA_DOWN = "raw_data_down"
    IDENTIFIER_SETUP = "setup"
    IDENTITY_ADMIN = "0"
    IDENTITY_GUEST = "1"
    IDENTITY_PROVISION = "2"
    KEY_CLIENT_ID = "clientId"
    KEY_IOT_NeedRsp = "NeedRsp"
    KEY_IOT_NeedRsp_EX = "NeedRspEx"
    KEY_IOT_PERFORMANCE_EVENT_REQ = "req"
    KEY_IOT_PERFORMANCE_EVENT_RES = "res"
    KEY_IOT_PERFORMANCE_ID = "IotPerformanceId"
    KEY_IOT_QOS = "QosLevel"
    KEY_IOT_QOS_EX = "QosLevelEx"
    KEY_SIGN_METHOD = "signMethod"
    KEY_SIGN_VALUE = "sign"
    LINK_DEFAULT_CONNECT_ID = "LINK_DEAFULT"
    MAX_BLOCK_SIZE = 3072
    MAX_DEVICE_MODEL_LENGTH = 3072
    METHOD_AUTH_USER = "core.service.user"
    METHOD_DEVICE_NOTIFY = "core.service.notify"
    METHOD_HEART_BEAT = "core.service.heartBeat"
    METHOD_IDENTIFIER_DEV = "dev"
    METHOD_PROPERTY_GET = "thing.service.property.get"
    METHOD_PROPERTY_POST = "thing.event.property.post"
    METHOD_PROPERTY_SET = "thing.service.property.set"
    METHOD_SERVICE_AUTH = "core.service.auth"
    METHOD_SERVICE_AUTH_INFO = "core.service.auth_info"
    METHOD_SERVICE_DISCOVERY = "core.service.dev"
    METHOD_SERVICE_PRE = "thing.service."
    METHOD_SETUP = "core.service.setup"
    METHOD_TSL_TEMPLATE = "thing.dsltemplate.get"
    METHOD_URI_PRE = "thing/service"
    METHOD_USER_SERVICE = "core.service.user"
    MODEL_TYPE_ALI_LCA_CLOUD = "4"
    MODE_VALUE_RANDW = "rw"
    MODE_VALUE_READ = "r"
    MODE_VALUE_WRITE = "w"
    MQTT_NOTIFY_TOPIC_PREFIX = "/app/down/_thing"
    MQTT_TOPIC_EVENTS = "/app/down/thing/events"
    MQTT_TOPIC_NOTIFY = "/app/down/_thing/event/notify"
    MQTT_TOPIC_PREFIX = "/app/down/thing"
    MQTT_TOPIC_PROPERTIES = "/app/down/thing/properties"
    MQTT_TOPIC_SERVICE_REPLY = "/app/down/thing/service/invoke/reply"
    MQTT_TOPIC_STATUS = "/app/down/thing/status"
    OPTIONNUMREGISTRY_ACCESSKEY = 36  # deprecated
    PATH_DISCOVERY = "/dev/core/service/dev"
    PATH_GROUP_PRE = "/thing/service/"
    PATH_NOTIFY = "/dev/core/service/notify"
    PATH_SETUP = "/core/service/setup"
    PAYLOAD_CODE = "code"
    PRODUCT_KEY_POSITION = 1
    PROPERTY_IDENTIFIER = "identifier"
    PROPERTY_IDENTIFIER_GET = "get"
    PROPERTY_IDENTIFIER_SET = "set"
    PROPERTY_NAME = "name"
    PROPERTY_TIME = "time"
    PROPERTY_URI_PRE = "thing/service/property"
    PROPERTY_VALUE = "value"
    REQUEST_DELAYTIME = "delayTime"
    REQUEST_ID = "id"
    REQUEST_METHOD = "method"
    REQUEST_PARAMS = "params"
    REQUEST_SESSIONKEY = "sessionKey"
    REQUEST_VERSION = "version"
    RESULT_FAIL = "Failed"
    RESULT_OK = "Success"
    RRESPONSE_DATA = "data"
    RRESPONSE_MESSAGEID = "messageId"
    SERVICE_CALLTYPE = "callType"
    SERVICE_DESC = "desc"
    SERVICE_IDENTIFIER = "identifier"
    SERVICE_INPUTDATA = "inputData"
    SERVICE_METHOD = "method"
    SERVICE_NAME = "name"
    SERVICE_OUTPUTDATA = "outputData"
    SESSION_VALID_TIME = 86400  # deprecated
    TAG = "[Tmp]"
    THING_WIFI_STATUS_NOTIFY = "thing/wifi/status/notify"
    TMP_MODEL_TYPE_ALI_BREEZE = "breeze"
    TMP_MODEL_TYPE_ALI_LCA_CLOUD = "cloudlca"
    TMP_MODEL_TYPE_ALI_THIRD_PART = "third"
    TMP_MODEL_TYPE_ALI_WIFI = "wifi"
    TYPE_VALUE_ARRAY = "array"
    TYPE_VALUE_BOOLEAN = "bool"
    TYPE_VALUE_DATE = "date"
    TYPE_VALUE_DOUBLE = "double"
    TYPE_VALUE_ENUM = "enum"
    TYPE_VALUE_FLOAT = "float"
    TYPE_VALUE_INTEGER = "int"
    TYPE_VALUE_STRING = "string"
    TYPE_VALUE_STRUCT = "struct"
    TYPE_VALUE_TEXT = "text"
    UNKNOWN_CODE = 0  # deprecated
    URI_ALINK_DEVICE_DATA = "alink/deviceStatus"  # deprecated
    URI_ALINK_SERVICE = "alink/service"  # deprecated
    URI_AUTH = "/auth"  # deprecated
    URI_AUTHEN_REGISTER = "/sys/{productKey}/{deviceName}/thing/authen/sub/register"
    URI_AUTHEN_REGISTER_REPLY = "/sys/{productKey}/{deviceName}/thing/authen/sub/register_reply"
    URI_BLACKLIST_UPDATE_POST = "/thing/lan/blacklist/update"
    URI_BLACKLIST_UPDATE_REPLY_POST = "/thing/lan/blacklist/update_reply"
    URI_DEVICE = "/device/core/dev"
    URI_DEV_PATH_PRE = "dev"
    URI_METHOD = "/device/core/method"
    URI_MODEL = "/model"
    URI_PATH_SPLITER = "/"
    URI_PERMISSION = "/permission"
    URI_PREFIX_ALCS_SERVICE = "core/service"
    URI_PREFIX_UPDATE_POST = "/thing/lan/prefix/update"
    URI_PREFIX_UPDATE_REPLY_POST = "/thing/lan/prefix/update_reply"
    URI_PRODUCT_DEVICE_REPLACE = "{deviceName}"
    URI_PRODUCT_PRODUCT_REPLACE = "{productKey}"
    URI_PROPERTY_SET = "/thing/service/property/set"
    URI_SYS_PATH_PRE = "sys"
    URI_THING = "/thing"
    URI_TOPIC_LOCALDEVICE_STATECHANGE = "group/localstatechange"
    URI_TOPIC_REPLY_POST = "_reply"
    URI_UPDATE_DEVICE_INFO = "/sys/{productKey}/{deviceName}/thing/deviceinfo/update"
    URI_UPDATE_DEVICE_INFO_REPLY = "/sys/{productKey}/{deviceName}/thing/deviceinfo/update_reply"
    URI_USER = "/user"
    VALUE_SHA256 = "sha256"
    VERSION = "1.0"
    WIFI_STATUS_KEY = "status"
    WIFI_STATUS_NOTIFY_PARAMS = "params"
